@@ -1,6 +1,11 @@
 # BASIC FUNCTION
 from aitool.basic_function.basic import split_dict
 from aitool.basic_function.basic import replace_char
+from aitool.basic_function.basic import is_appear
+
+from aitool.basic_function.security import encrypt_md5
+
+from aitool.basic_function.deduplication import Deduplication
 
 from aitool.basic_function.file import file_exist as file_exist
 from aitool.basic_function.file import dump_json as dump_json
