@@ -13,8 +13,8 @@ from tqdm import tqdm
 import math
 import functools
 import zipfile
-from typing import Any, List, Union, NoReturn
-from aitool import split_dict
+from typing import Any, List, Union, NoReturn, Set
+from aitool import split_dict, Deduplication
 
 
 def file_exist(file: str) -> bool:
@@ -81,9 +81,25 @@ def load_line(
         separator: Union[None, str] = None,
         separator_time: int = -1,
         form: str = None,
-) -> List[Any]:
-    with open(file, 'r', encoding='utf8') as fin:
-        for line in fin:
+        deduplication: bool = False,
+        use_open: bool = False,
+) -> Union[str, List[str], Set[str]]:
+    """
+    按行读入文件，会去掉每行末尾的换行符
+    :param file: 文件路径
+    :param separator: 用separator切分每行内容，None表示不做切分
+    :param separator_time: 控制separator的切分次数，-1表示不限制次数
+    :param form: 若为'set'会用set格式输出每行的结果
+    :param deduplication: 若为True，将不输出重复的行
+    :param use_open: 若为False，将用fileinput打开文件，而非用open
+    :return: 文件每行的内容
+    """
+    cache = Deduplication()
+
+    def inner_line_process(_file_iterator):
+        for line in _file_iterator:
+            if deduplication and cache.is_duplication(line):
+                continue
             item = line.rstrip('\n\r')
             if separator:
                 if separator_time == -1:
@@ -94,22 +110,38 @@ def load_line(
                 item = set(item)
             yield item
 
+    if use_open:
+        file_iterator = open(file, 'r', encoding='utf8')
+    else:
+        file_iterator = fileinput.input([file])
+    yield from inner_line_process(file_iterator)
+    file_iterator.close()
+
 
 def load_big_data(
         file: str,
         separator: Union[None, str] = None,
         separator_time: int = -1,
         form: str = None,
-) -> List[Any]:
-    warnings.warn("load_big_data 和 load_line 的功能一样，但内部实现不同，推荐优先使用load_line ", DeprecationWarning)
-    for line in fileinput.input([file]):
-        item = line.rstrip('\n\r')
-        if separator:
-            if separator_time == -1:
-                item = item.split(separator)
-            else:
-                item = item.split(separator, separator_time)
-        yield item
+        deduplication: bool = False,
+) -> Union[str, List[str], Set[str]]:
+    """
+    按行读入文件，会去掉每行末尾的换行符
+    :param file: 文件路径
+    :param separator: 用separator切分每行内容，None表示不做切分
+    :param separator_time: 控制separator的切分次数，-1表示不限制次数
+    :param form: 若为'set'会用set格式输出每行的结果
+    :param deduplication: 若为True，将不输出重复的行
+    :return: 文件每行的内容
+    """
+    warnings.warn("已合并到load_line，可通过use_open=False调用", DeprecationWarning)
+    yield from load_line(
+        file=file,
+        separator=separator,
+        separator_time=separator_time,
+        form=form,
+        deduplication=deduplication,
+    )
 
 
 def load_lines(
@@ -117,11 +149,15 @@ def load_lines(
         separator: Union[None, str] = None,
         separator_time: int = -1,
         form: str = None,
+        deduplication: bool = False,
 ) -> List[Any]:
     data = []
+    cache = Deduplication()
     with open(file, 'r', encoding='utf8') as fin:
-        for d in fin.readlines():
-            item = d.rstrip('\n\r')
+        for line in fin.readlines():
+            if deduplication and cache.is_duplication(line):
+                continue
+            item = line.rstrip('\n\r')
             if separator:
                 if separator_time == -1:
                     item = item.split(separator)
@@ -265,6 +301,8 @@ def prepare_data(url: str, directory: str = '', packed: bool = False, pack_way:
 
 
 if __name__ == '__main__':
-    test_data = [[i] for i in range(26)]
-    test_file = 'test.xlsx'
-    dump_excel(test_data, test_file)
+    # test_data = [[i] for i in range(26)]
+    # test_file = 'test.xlsx'
+    # dump_excel(test_data, test_file)
+    for text in load_line('A.log'):
+        print(text)
